@@ -197,7 +197,7 @@ class Compressor(object):
     def read_file(self, path):
         """Read file content in binary mode"""
         file = storage.open(path, 'rb')
-        content = file.read()
+        content = file.read().decode('utf-8')
         file.close()
         return content
 
@@ -222,10 +222,10 @@ class SubProcessCompressor(CompressorBase):
     def execute_command(self, command, content):
         pipe = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE,
             stdin=subprocess.PIPE, stderr=subprocess.PIPE)
-        pipe.stdin.write(content)
+        pipe.stdin.write(content.encode('utf-8'))
         pipe.stdin.close()
 
-        compressed_content = pipe.stdout.read()
+        compressed_content = pipe.stdout.read().decode('utf-8')
         pipe.stdout.close()
 
         error = pipe.stderr.read()
