@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+import coverage
 import os
 import sys
 
@@ -30,8 +31,24 @@ from django.test.simple import run_tests
 def runtests(*test_args):
     if not test_args:
         test_args = ['tests']
+    parent_dir = os.path.join(TEST_DIR, "..")
     sys.path.insert(0, os.path.join(TEST_DIR, ".."))
+    cover = coverage.coverage(branch=True, cover_pylib=False,
+        include=[
+            os.path.join(parent_dir, 'pipeline', '*.py')
+        ],
+        omit=[
+            os.path.join(parent_dir, 'tests', '*.py'),
+            os.path.join(parent_dir, 'pipeline', 'compressors',
+                'jsmin', 'jsmin.py'),
+        ]
+    )
+    cover.load()
+    cover.start()
     failures = run_tests(test_args, verbosity=1, interactive=True)
+    cover.stop()
+    cover.save()
+    cover.report(file=sys.stdout)
     sys.exit(failures)
 
 
